@@ -17,7 +17,7 @@ from dask_cloudprovider.aws.helper import (
 from dask_cloudprovider.utils.timeout import Timeout
 
 try:
-    import aiobotocore
+    from aiobotocore.session import get_session
     import botocore.exceptions
 except ImportError as e:
     msg = (
@@ -332,7 +332,7 @@ class EC2Cluster(VMCluster):
     ...     credentials = parser.items('default')
     ...     all_credentials = {key.upper(): value for key, value in [*config, *credentials]}
     ...     with contextlib.suppress(KeyError):
-    ...     all_credentials["AWS_REGION"] = all_credentials.pop("REGION")
+    ...         all_credentials["AWS_REGION"] = all_credentials.pop("REGION")
     ...     return all_credentials
     >>> cluster = EC2Cluster(env_vars=get_aws_credentials())
 
@@ -407,7 +407,7 @@ class EC2Cluster(VMCluster):
         debug=False,
         **kwargs,
     ):
-        self.boto_session = aiobotocore.get_session()
+        self.boto_session = get_session()
         self.config = dask.config.get("cloudprovider.ec2", {})
         self.scheduler_class = EC2Scheduler
         self.worker_class = EC2Worker
