@@ -57,6 +57,7 @@ class GCPInstance(VMInterface):
         source_image=None,
         docker_image=None,
         network=None,
+        network_projectid=None,
         env_vars=None,
         ngpus=None,
         gpu_type=None,
@@ -87,6 +88,9 @@ class GCPInstance(VMInterface):
         self.disk_type = disk_type or self.config.get("disk_type")
         self.ngpus = ngpus or self.config.get("ngpus")
         self.network = network or self.config.get("network")
+        self.network_projectid = (
+            network_projectid if network_projectid is not None else projectid
+        )
         self.gpu_type = gpu_type or self.config.get("gpu_type")
         self.gpu_instance = gpu_instance
         self.bootstrap = bootstrap
@@ -96,6 +100,7 @@ class GCPInstance(VMInterface):
         self.general_zone = "-".join(self.zone.split("-")[:2])  # us-east1-c -> us-east1
 
     def create_gcp_config(self):
+        subnetwork = f"projects/{self.network_projectid}/regions/{self.general_zone}/subnetworks/{self.network}"
         config = {
             "name": self.name,
             "machineType": f"zones/{self.zone}/machineTypes/{self.machine_type}",
@@ -124,7 +129,7 @@ class GCPInstance(VMInterface):
             "networkInterfaces": [
                 {
                     "kind": "compute#networkInterface",
-                    "subnetwork": f"projects/{self.projectid}/regions/{self.general_zone}/subnetworks/{self.network}",
+                    "subnetwork": subnetwork,
                     "aliasIpRanges": [],
                 }
             ],
@@ -289,7 +294,7 @@ class GCPScheduler(SchedulerMixin, GCPInstance):
             f"\n  Source Image: {self.source_image} "
             f"\n  Docker Image: {self.docker_image} "
             f"\n  Machine Type: {self.machine_type} "
-            f"\n  Filesytsem Size: {self.filesystem_size} "
+            f"\n  Filesystem Size: {self.filesystem_size} "
             f"\n  Disk Type: {self.disk_type} "
             f"\n  N-GPU Type: {self.ngpus} {self.gpu_type}"
             f"\n  Zone: {self.zone} "
@@ -397,6 +402,9 @@ class GCPCluster(VMCluster):
             - ingress 10.0.0.0/8 on all ports for internal communication of workers
             - ingress 0.0.0.0/0 on 8786-8787 for external accessibility of the dashboard/scheduler
             - (optional) ingress 0.0.0.0./0 on 22 for ssh access
+    network_projectid: str
+        The project id of the GCP network. This defaults to the projectid. There may
+        be cases (i.e. Shared VPC) when network configurations from a different GCP project are used.
     machine_type: str
         The VM machine_type. You can get a full list with ``gcloud compute machine-types list``.
         The default is ``n1-standard-1`` which is 3.75GB RAM and 1 vCPU
@@ -424,6 +432,8 @@ class GCPCluster(VMCluster):
         By default the ``daskdev/dask:latest`` image will be used.
     docker_args: string (optional)
         Extra command line arguments to pass to Docker.
+    extra_bootstrap: list[str] (optional)
+        Extra commands to be run during the bootstrap phase.
     ngpus: int (optional)
         The number of GPUs to atatch to the instance.
         Default is ``0``.
@@ -544,6 +554,7 @@ class GCPCluster(VMCluster):
         projectid=None,
         zone=None,
         network=None,
+        network_projectid=None,
         machine_type=None,
         on_host_maintenance=None,
         source_image=None,
@@ -589,6 +600,8 @@ class GCPCluster(VMCluster):
             "machine_type": self.machine_type,
             "ngpus": ngpus or self.config.get("ngpus"),
             "network": network or self.config.get("network"),
+            "network_projectid": network_projectid
+            or self.config.get("network_projectid"),
             "gpu_type": gpu_type or self.config.get("gpu_type"),
             "gpu_instance": self.gpu_instance,
             "bootstrap": self.bootstrap,
